# Axis with Inappropriate Members
Rule ID: DQC_0001  
Status:  Final  
Release date: September 29, 2016
Effective date: January 1, 2017

## Rule function
Certain axes in the US GAAP taxonomy should only have certain members as shown in the US GAAP taxonomy. This rule tests whether these axes have inappropriate members.

Certain axes can have custom or extended (i.e., company specific) members. This rule also tests whether only these axes have custom members and, therefore, limits the use of custom or extended members to those situations where they are appropriate because the member is unique to the filer.

The rule evaluates a company’s extension taxonomy and instance document and flags an error when there is an inappropriate axis/member combination in the extension taxonomy even though there is no fact associated with the axis/member combination in the instance document.

## Data Quality Guidance

This rule verifies compliance with DQC Guidance on Tagging Axis and Members Using the US GAAP Taxonomy.

## Authoritative references
### [SEC Staff Observations November 1, 2010](https://www.sec.gov/structureddata/osd_staffobs_11-01-10.html)
#### Observations on Consolidated Registrant with Subsidiaries
The SEC identified where the "Legal Entity Axis" has been used for purposes other than to tag information about the consolidated entity and its subsidiaries. The following comments are used as the basis for this rule:

1. **Consolidated Entity Facts:**
  * For facts that apply only to the Consolidated Entity, do not use the LegalEntityAxis.
  * Not using this axis means all the facts in an instance relate to the consolidated entity. (EFM 6.6.5).
2. **Parent Company Facts:**
  * Use the domain member element "Parent Company Member" for facts that apply only to the parent holding company, corporate headquarters, or similar legal entity not associated with any specific subsidiary (EFM 6.6.7).  (The entity associated with Corporate Headquarters can be used as a basis to determine what is the parent company.)
  * The parent company member should not be used as the default for the consolidated entity.
3. **Subsidiary Facts:**
  * Create a separate domain member element for each subsidiary. Typically, the element name for subsidiary ABCD would be "ABCDMember" and appear on the "Legal Entity Axis". (EFM 6.6.5).
  * Note that there is no restriction on using company-specific or period-specific information in the member name. (FAQ E.20)
  * Note that members created for an entity with subsidiaries apply collectively to all subsidiaries of that entity.

#### Observation on US GAAP modeling of Axis and Members
The SEC also noted circumstances where filers have not used the modeling of elements currently published in the US GAAP Taxonomy. The SEC suggested filers utilize the pre-defined table structures included in the taxonomy, and use the related line item elements and domain members to the extent they are applicable for their specific circumstances. (FAQ E.16)

### FASB Implementation Guides

1. [FASB Taxonomy Implementation Guide Segment Reporting](http://www.fasb.org/cs/ContentServer?c=Document_C&pagename=FASB%2FDocument_C%2FDocumentPage&cid=1176167943040) (DQC_0001.70)
2. [FASB Taxonomy Implementation Guide Subsequent Events](http://www.fasb.org/cs/ContentServer?c=Document_C&pagename=FASB%2FDocument_C%2FDocumentPage&cid=1176167943133) (DQC_0001.74)

## Problem solved by the rule
If certain axes have inappropriate standard members, consumption of the data is adversely impacted because the resulting axis and member combinations are nonsensical, e.g., reporting a type of currency as a member on a debt instrument axis.

If an axis has inappropriate custom or extended elements for members that are not unique to the filer, automated analysis is more difficult because the use of these members is not expected on the axis.

Consumers, in certain circumstances, can use a standard axis to understand the nature of extension members. For example, if a company reports the values of underlying individual securities comprising equity or fixed income securities but does not report a subtotal for fixed income or equity securities, the nature of individual securities represented as extensions would be understood because the extensions would be represented as a component of the standard elements for equity or fixed income securities.  If the company uses a standard member that is not a type of investment security it is impossible to understand the nature of the extensions used for underlying individual securities.

## Example rule message
(Note: Presentation style of rule messages may differ among software implementations of the rules.
)

There are two message types associated with this rule.  The first two messages report  when there is a fact associated with the axis member combination and the third message is reported when no fact is associated with the axis and member combination.

The rule message associated with an inappropriate extended member on an axis associated with a fact is as follows:

The extension member, Euro [Member] is used on the Currency [Axis] with the element Revenues with a value of 120,000,000.  Extension members should not be used with the Currency [Axis].  
The properties of this us-gaap:Revenues fact are:  
Period: 2015-01-01 to 2015-09-30  
Dimensions: CurrencyAxis = EuroMember    
Unit: USD
Rule version: 1.0

The rule message associated with a member from the US GAAP taxonomy used with an inappropriate axis is as follows:

The member, Land [Member] is used on the axis Position [Axis] with the element Property Plant and Equipment Gross with a value of 150,000,000.  This member should not be used with the Position [Axis].  
The properties of this us-gaap:PropertyPlantAndEquipmentGross fact are:  
Period: 2015-01-01 to 2015-09-30  
Dimensions: PositionAxis = LandMember    
Unit: USD
Rule version: 1.0

The rule message associated with an inappropriate axis member combination where there is no associated fact, is as follows:

The member, Euro [Member], is used on the axis, Currency [Axis] in the disclosure group “004120 - Disclosure - Debt Instruments (Details)”. There are no facts associated with this member and axis.  Extension members should not be used with the Currency [Axis].  
Rule version: 1.0

## For Developers
The Global Rule Logic document contains general guidelines for implementation of rules.
The rule message template contains text and parametric reference to arguments of the rule operation, using the syntax ${parameter} to indicate that insertion of a parameter’s value is to occur.

### Message template

The rule template associated with an inappropriate extended member on an axis associated with a fact is as follows:

The extension member, ${Rule.member.label} is used on the axis ${Rule.axis.label} with the element ${fact1.label} with a value of ${fact1.value}.  Extension members should not be used with the ${Rule.axis.label}.  
The properties of this ${fact1.name} fact are:  
Period: ${fact1.period}  
Dimensions: ${fact1.dimensions}  
Unit: ${fact1.unit}  
Rule version: ${ruleVersion}

The rule template associated with a member from the US GAAP taxonomy used with an inappropriate axis is as follows:

The member, ${Rule.member.label} is used on the axis ${Rule.axis.label} with the element ${fact1.label} with a value of ${fact1.value}.  This member should not be used with the ${Rule.axis.label].  
The properties of this ${fact1.name} fact are:  
Period: ${fact1.period}  
Dimensions: ${fact1.dimensions}  
Unit: ${fact1.unit}  
Rule version: ${ruleVersion}

The rule message associated with an inappropriate axis member combination where there is no associated fact, is as follows:

The member, ${Rule.member.label}, is used on the axis, ${Rule.axis.label} in the disclosure group ${group}. There are no facts associated with this member and axis.  Extension members should not be used with the ${Rule.axis.label}.  
Rule version: ${ruleVersion}

### Identifying Allowable Members

The [DQC_0001_ListOfAxes spreadsheet](DQC_0001_ListOfAxes.xlsx?raw=true) details which members can appear on a given axis. The column "Members defined in standard taxonomy" is used to determine if members defined on the axis in the US GAAP taxonomy can be used in the company extension. If the value is "Yes" then the members defined in the US GAAP taxonomy can be used on the axis in the filing. If "None" this means that the axis has no members. This does not exclude the domain member from being used. Because there are many US GAAP taxonomies and the members on the axis can differ from year to year the developer should use the list of members on the taxonomy that is used by the specific filing.

The column "Members on additional UGT axes " is a list of additional axis whose members can also be used on the axis being tested. The developer should use the list of members included in the US GAAP taxonomy that is used by the specific filing.

The column "Additional UGT members " lists additional members from the US GAAP taxonomy that can be included on the axis.

The column "Extensions Allowed "can have values of either "Yes", "No" or "Limited". If the value is "Yes" then any extensions are allowed on the axis. If the the value is "No" then no extension members are allowed on the axis. If the value is "Limited" the a list of allowable extensions are defined in the column "Extensions allowed."

## Rule element ID index
The rule element id is used to identify unique elements or combinations of elements tested in the rule.  
See [DQC_0001_ListOfAxes_V1](DQC_0001_ListOfAxes_V1.xlsx?raw=true) spreadsheet for rule element ids.

© Copyright 2016, XBRL US Inc. All rights reserved.   
See [License](../../License.md) for license information.  
See [Patent Notice](../../PatentNotice.md) for patent infringement notice.
