# DEI and Block Tag Date Contexts 
Rule ID: DQC_0006   
Status: Final  
Release date: November 19, 2015  
Effective date: January 1, 2016

## Rule function

This rule tests that the dates used for certain Document and Entity Information, accounting policy, text block and table text block elements are consistent with the fiscal period focus of the filing (e.g. Q1, Q2, Q3 or FY). 

In general, filings cover quarterly and annual periods in roughly 90 day increments. Due to allowable variations in reporting period length, filing periods may be more or less than the standard increment. The increments tested for each filing period are as follows:

	Q1	65 to 115 days

	Q2	155 to 205 days

	Q3	245 to 295 days

	FY	340 to 390 days

The following Document and Entity Information elements are included in this test:

	Amendment Description
	Amendment Flag
	Current Fiscal Year End Date
	Document Period End Date
	Document Fiscal Year Focus
	Document Fiscal Period Focus
	Document Type
	Entity Registrant Name
	Entity Central Index Key
	Entity Filer Category

This rule does not test any non numeric items that are not text block, table text block, and accounting policy elements.

This rule also does not test any transition period filings, which are identified by the letter "T" in the form name. Transition period filings are submitted when a filer changes their fiscal year. Transition period filings may cover periods which are different from the general quarter or annual length.

This rule currently tests filings from filers who incorporate and begin filing during the year. Although the rule will return an error message for these filings, they are valid exceptions to the rule. These cases are very rare.

## Authoritative reference

EDGAR Filer Manual 6.6.1; EDGAR Filer Manual 6.6.2 requires the dates for text blocks, table text blocks, and accounting policy elements must be the current reporting period. This is true even when the information in the text blocks, table text blocks or accounting policies relates to a prior period.

## Problem solved by the rule

Filers apply incorrect reporting dates to elements. This error impacts the consumption of the elements because users will extract the data based on the expected reporting date.  

## Example rule message 
(Note: Presentation style of rule messages may differ among software implementations of the rules.)

The number of days, 270, in the date range reported for Document Type, 2015-01-01 to 2015-09-30 is not consistent with the Document Fiscal Period Focus value of Q2.   
The properties of this dei:DocumentType fact are:   
Period: 2015-01-01 to 2015-09-30   
Dimensions: none   
Unit: none   
Rule version: 1.0

## For Developers

The Global Rule Logic document contains general guidelines for implementation of rules.

The rule message template contains text and parametric reference to arguments of the rule operation, using the syntax ${parameter} to indicate that insertion of a parameter's value is to occur. 

### Message template

The number of days, ${fact1.period.durationDays},  in the date range reported for ${fact1.label}, ${fact1.period.startDate} to ${fact1.period.endDate} is not consistent with the ${dei:DocumentFiscalPeriodFocus.fact.label} value of ${dei:DocumentFiscalPeriodFocus.fact.value}.   
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### Rule element ID index

The rule element id is used to identify unique elements or combinations of elements tested in the rule.

| Rule element ID | Element label | Element name
| ----- | ----- | ----- |
| DQC_0006.14 | Document Fiscal Period Focus | DocumentFiscalPeriodFocus | 


© Copyright 2015 - 2016, XBRL US Inc. All rights reserved.   
See [License](../../License.md) for license information.  
See [Patent Notice](../../PatentNotice.md) for patent infringement notice.
