# Negative Values With No Dimensions
Rule ID: DQC_0014  
Status:  Final  
Release date: September 29, 2016
Effective date: January 1, 2017

## Rule function
The US GAAP Taxonomy is designed so that the majority of elements have a positive value. This rule tests that the values for a given list of elements with no dimensions are negative.  If the value has a dimension member, then the rule will not fire.

See file DQC_0014_ListOfElements which provides a list of elements that should not be negative. The rule tests whether these elements have a negative value in an XBRL document. The elements in this list are distinct from the elements listed in DQC_0015_ListOfElements because these elements will only be tested when no dimensions are associated with the values.

## Authoritative reference
SEC Staff Observations December 13, 2011, June 15, 2011, November 1, 2010, October 6, 2009

The US GAAP taxonomy is designed for the majority of elements to have a positive value, so that the value reported in the XBRL document represents the correct balance type for the element (e.g., debit balance type for assets and expenses and losses or credit balance type for liabilities and income and gains). If the value reported in the HTML document is shown with parentheses, the value reported in the XBRL document should still be positive, other than as described in the following sentence. In some limited cases, if the value also has a specified member associated with it, the value may be negative (e.g., when an element is used for an adjustment or elimination, the value may need to be negative).

If the value reported in the HTML document is shown in parenthesis (e.g., interest expense or loss on disposition of assets), you may use a negated label to present the value in parenthesis in the SEC Interactive Data viewer without changing the positive value reported in the XBRL document. The value reported in the XBRL document (e.g., interest expense or loss on disposition of assets) should be the same as the value reported in the HTML document, even though the value in the HTML document is shown in parenthesis. Therefore, it is an error to change the value reported in the XBRL document to a negative solely because the value reported in the HTML document is shown in parenthesis.

## Problem solved by the rule
Filers continue to have incorrect negative amounts in files, which is inconsistent with the balance types and definitions of the elements used and the structure of the US GAAP Taxonomy. Incorrect values in a filing makes it difficult or impossible to use that data for automated analysis.

## Example rule message
An example of the general rule message is shown below. If a message is not defined for a specific set of elements, the general rule message is used.
### General rule message example
Derivative Assets has a value of -400,000 which is less than zero. This element should not have a negative value.
The properties of this us-gaap:DerivativeAssets fact are:
Period: 2012-12-31
Dimensions: none
Unit: USD
Rule version: 1.0
## For Developers
The Global Rule Logic document contains general guidelines for implementation of rules.
The rule message template contains text and parametric reference to arguments of the rule operation, using the syntax ${parameter} to indicate that insertion of a parameter’s value is to occur.
### General message template
${fact1.label} has a value of ${fact1.value} which is less than zero. This element should not have a negative value.
The properties of this ${fact1.name} fact are:
Period: ${fact1.period}
Unit: ${fact1.unit}
Rule version: ${ruleVersion}
## Rule element ID index
The rule element id is used to identify unique elements or combinations of elements tested in the rule.

See [DQC_0014_ListOfElements_V2](DQC_0014_ListOfElements_V2.xlsx?raw=true) spreadsheet for rule element ids.

© Copyright 2016, XBRL US Inc. All rights reserved.   
See [License](../../License.md) for license information.  
See [Patent Notice](../../PatentNotice.md) for patent infringement notice.
