# Negative Values
Rule ID: DQC_0015   
Status: Final  
Release date: November 19, 2015  
Effective date: January 1, 2016
Latest Committee-approved update: September 29, 2016 (see rule appendix for details)

## Rule function

The US GAAP Taxonomy is designed so that the majority of elements have a positive value. This rule tests whether the values for a given list of elements are negative. The rule does not test elements when a specified member is present which would allow the value to be negative.

See file [DQC_0015_ListOfElements](DQC_0015_ListOfElementsV2.xlsx?raw=true)  which provides a list of elements that should not be negative. The rule tests whether these elements have a negative value in an XBRL document.  The elements are listed in order of most commonly occurring errors.

See file [DQC_0015_MemberExclusions](DQC_0015_MemberExclusions_V2.xlsx?raw=true) for a list of members that, when used with these elements, allow the value of the element to be negative.  The rule does not test these member/element combinations.

## Authoritative reference

SEC Staff Observations December 13, 2011, June 15, 2011, November 1, 2010, October 6, 2009  

The US GAAP taxonomy is designed for the majority of elements to have a positive value, so that the value reported in the XBRL document represents the correct balance type for the element (e.g., debit balance type for assets and expenses and losses or credit balance type for liabilities and income and gains). If the value reported in the HTML document is shown with parentheses, the value reported in the XBRL document should still be positive, other than as described in the following sentence. In some limited cases, if the value also has a specified member associated with it, the value may be negative (e.g., when an element is used for an adjustment or elimination, the value may need to be negative).

If the value reported in the HTML document is shown in parenthesis (e.g., interest expense or loss on disposition of assets), you may use a negated label to present the value in parenthesis in the SEC Interactive Data viewer without changing the positive value reported in the XBRL document. The value reported in the XBRL document (e.g., interest expense or loss on disposition of assets) should be the same as the value reported in the HTML document, even though the value in the HTML document is shown in parenthesis. Therefore, it is an error to change the value reported in the XBRL document to a negative solely because the value reported in the HTML document is shown in parenthesis.

## Problem solved by the rule

Filers continue to have incorrect negative amounts in files, which is inconsistent with the balance types and definitions of the elements used and the structure of the US GAAP Taxonomy. Incorrect values in a filing makes it difficult or impossible to use that data for automated analysis.

## Example rule message
(Note: Presentation style of rule messages may differ among software implementations of the rules.)

An example of the general rule message is shown below. Appendix A details specific rule messages for certain elements. If a message is not defined for a specific set of elements, the general rule message is used.

### General rule message example

Accrued Liabilities And Other Liabilities has a value of -400,000 which is less than zero. This element should not have a negative value.    
The properties of this us-gaap:AccruedLiabilitiesAndOtherLiabilities fact are:   
Period: 2012-12-31   
Dimensions: none   
Unit: USD   
Rule version: 1.0

## For Developers

The Global Rule Logic document contains general guidelines for implementation of rules.

The rule message template contains text and parametric reference to arguments of the rule operation, using the syntax ${parameter} to indicate that insertion of a parameter's value is to occur.

### General message template

${fact1.label} has a value of ${fact1.value} which is less than zero. This element should not have a negative value.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### Rule element ID index

The rule element id is used to identify unique elements or combinations of elements tested in the rule.

See [DQC_0015_ListOfElementsV2](DQC_0015_ListOfElementsV2.xlsx?raw=true) and [DQC_0015_MemberExclusions_V2](DQC_0015_MemberExclusions_V2.xlsx?raw=true) spreadsheets for rule element ids.

## Appendix A - Specific rule messages

### DQC_0015.243 (Adjustments to Additional Paid in Capital, Income Tax Benefit from Share-based Compensation)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element represents the excess tax benefit associated with share based compensation, and excludes tax deficiencies that occur when the value of the stock based compensation is less than the compensation expense recognized. If this is a tax deficiency, use the element Adjustments to Additional Paid in Capital, Income Tax Deficiency from Share-based Compensation.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}      
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.262 (Amortization of Lease Incentives)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element represents the amortization of lease incentives offered by the lessor to the lessee, and should only be used by the lessor to reflect the allocated expense associated with the incentive over the life of the lease.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.310 (Available-for-sale Securities, Accumulated Gross Unrealized Loss, before Tax)

${fact1.label} has a value of ${fact1.value} which is less than zero.  This element represents the total losses on available for sale securities with net losses reported in accumulated other comprehensive income.  The value of this element cannot be negative, as that would represent a gain on available for sale securities. If this is a gain, use the element Available-for-sale Securities, Accumulated Gross Unrealized Gain, before Tax.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.456 (Capital Leases, Future Minimum Payments, Executory Costs)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element should be a positive amount as it represents the  insurance, maintenance, and taxes to be paid by the lessor that offset the future minimum payments of the lessee.     
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.457 (Capital Leases, Future Minimum Payments, Interest Included in Payments)

${fact1.label} has a value of ${fact1.value} which is less than zero. It represents the difference between the total future minimum lease payments and the discounted present value of those lease payments.  It is often shown as a deduction from the total minimum lease payments to calculate the present value of the minimum lease payments.  A negative value would imply a negative interest rate which is unlikely.     
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.476 (Cash Acquired in Excess of Payments to Acquire Business)

${fact1.label} has a value of ${fact1.value} which is less than zero. If a negative value was reported to represent payments greater than the cash acquired, use the element Payments to Acquire Businesses, Net of Cash Acquired.   
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.493 (Certain Loans Acquired in Transfer Accounted for as Debt Securities, Accretable Yield, Accretion)

${fact1.label} has a value of ${fact1.value} which is less than zero. In the roll forward of accretable yield, the accretion amount is deducted and is often shown as a negative value.  However, the accretion amount that reduces the balance should be reported as a positive amount.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.496 (Certain Loans Acquired in Transfer, Accretable Yield)

${fact1.label} has a value of ${fact1.value} which is less than zero. This amount is often shown as a deduction from contractual cash flows to calculate the value of loans accounted for under ASC 310-30.  It should be reported as a positive amount.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.497 (Certain Loans Acquired in Transfer Not Accounted for as Debt Securities, Accretable Yield, Accretion)

${fact1.label} has a value of ${fact1.value} which is less than zero. In the roll forward of accretable yield, the accretion amount is deducted and is often shown as a negative value.  However, the accretion amount that reduces the balance should be reported as a positive amount.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.629 (Deferred Tax Assets, Tax Deferred Expense)

${fact1.label} has a value of ${fact1.value} which is less than zero. If the element is negative because it represents a deferred tax liability, use the element Deferred Tax Liabilities, Deferred Expense.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.633 (Deferred Tax Assets, Valuation Allowance)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element is often shown as a reduction in deferred tax assets.  This element should be reported with a positive value when it reduces the value of deferred tax assets.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.640 (Deferred Tax Liabilities, Derivatives)

${fact1.label} has a value of ${fact1.value} which is less than zero. If a deferred tax asset is being reported for derivatives, use the element Deferred Tax Assets, Derivative Instruments.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.951 (Extinguishment of Debt, Amount)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element should not be used to represent a repayment of debt on the cash flow statement. To represent the repayment of debt on the cash flow statement, use an element representing repayments of debt.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.1032 (Fair Value, Measurement with Unobservable Inputs Reconciliation, Liability, Transfers Into Level 3)

${fact1.label} has a value of ${fact1.value} which is less than zero. If it is entered as a negative amount to represent a transfer out of Level 3, use the element Fair Value, Measurement with Unobservable Inputs Reconciliation, Liability, Transfers out of Level 3 to represent the reduction in Level 3 liabilities.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.1240 (Gain on Derivative Instruments, Pretax)

${fact1.label} has a value of ${fact1.value} which is less than zero. If the item represents a gross loss on derivative instruments, use the element Loss on Derivative Instruments, Pretax. If it represents a net loss on derivative instruments, use the element Gain (Loss) on Derivative Instruments, Net, Pretax.   
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.1306 (Effective Income Tax Rate Reconciliation, Nondeductible Expense, Research and Development, Amount)

${fact1.label} has a value of ${fact1.value} which is less than zero. If this element is a research tax credit, use the element Effective Income Tax Rate Reconciliation, Tax Credit, Research, Amount. If it is nondeductible research and development expense it should be entered as a positive amount.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.1428 (Derivative, Notional Amount)

${fact1.label} has a value of ${fact1.value} which is less than zero. If this represents a short position, use the Position Axis and Short Member with this element to indicate the notional derivative amount is in a short position, and report the value as a positive amount.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.1615 (Loans and Leases Receivable, Related Parties, Collections)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element represents the receipt of collections from related parties which reduces the receivables balance, and not the receipt of cash.    
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

### DQC_0015.2169 (SEC Schedule III, Real Estate, Improvements)

${fact1.label} has a value of ${fact1.value} which is less than zero. This element represents the increase in the value of real estate during the period, and not the cash payments made for real estate improvements. This element should not be used for payments for capital improvements.   
The properties of this ${fact1.name} fact are:   
Period: ${fact1.period}   
Dimensions: ${fact1.dimensions}   
Unit: ${fact1.unit}   
Rule version: ${ruleVersion}

## Appendix B – Post-implementation edits

### Member Exclusion list revisions (effective):

**Axis changes**

*   Add AdjustmentsForChangeInAccountingPrincipleAxis (February 17, 2016)
*   Add AdjustmentsForNewAccountingPronouncementsAxis (February 17, 2016)
*   Add ChangeInAccountingEstimateByTypeAxis (April 6, 2016)
*   Add ErrorCorrectionsAndPriorPeriodAdjustmentsRestatementByRestatementPeriodAndAmountAxis (February 17, 2016)
*   Add PartnerCapitalComponentsAxis (April 6, 2016)
*   Add PartnerTypeOfPartnersCapitalAccountAxis (April 6, 2016)
*   Add ProspectiveAdoptionOfNewAccountingPronouncementsAxis (February 17, 2016)
*   Add QuantifyingMisstatementInCurrentYearFinancialStatementsByNatureOfErrorAxis (February 17, 2016)
*   Add StatementBusinessSegmentsAxis (January 1, 2017)

**Member changes**

*   Add AllOtherSegmentsMember on StatementBusinessSegmentsAxis (April 6, 2016)
*   Add ChangeDuringPeriodFairValueDisclosureMember on FairValueByMeasurementBasisAxis (April 6, 2016)
*   Add CorporateAndOtherMember on StatementBusinessSegmentsAxis (April 6, 2016)
*   Add CorporateMember on StatementBusinessSegmentsAxis (April 6, 2016)
*   Add SubsidiaryIssuerMember to the Legal Entity Axis (February 17, 2016)
*   Add UnallocatedFinancingReceivablesMember on FinancingReceivablePortfolioSegmentAxis (May 17, 2016)
*   Change "Reconciliat" TO "Reconcili" (February 17, 2016)

### Line Item removals (effective):

*   AllocatedShareBasedCompensationExpense (248) (February 17, 2016)
*   DisposalGroupIncludingDiscontinuedOperationOperatingExpense (862) (May 17, 2016)
*   ExcessTaxBenefitFromShareBasedCompensationFinancingActivities (941) (February 17, 2016)
*   FairValueMeasurementWithUnobservableInputsReconciliationRecurringBasisLiabilitySettlements (1041) (May 17, 2016)
*   IncomeTaxReconciliationTaxExemptIncome (1308) (April 6, 2016)
*   InterestCreditedToPolicyOwnerAccounts (1366) (February 17, 2016)
*   NoncashOrPartNoncashAcquisitionNetNonmonetaryAssetsAcquiredLiabilitiesAssumed (1781) (February 17, 2016)
*   NoncashOrPartNoncashAcquisitionNetNonmonetaryAssetsAcquiredLiabilitiesAssumed1 (1782) (April 6, 2016)
*   PaymentsForProceedsFromFederalReserveBankStock (1937) (February 17, 2016)
*   RealEstateAndAccumulatedDepreciationCostsCapitalizedSubsequentToAcquisitionCarryingCosts (2164) (April 6, 2016)
*   RealEstateAndAccumulatedDepreciationCostsCapitalizedSubsequentToAcquisitionImprovements (2165) (April 6, 2016)
*   SECScheduleIIIRealEstateAndAccumulatedDepreciationCostsCapitalizedSubsequentToAcquisitionBuildingsAndImprovements (2320) (April 6, 2016)
*   SECScheduleIIIRealEstateAndAccumulatedDepreciationCostsCapitalizedSubsequentToAcquisitionLand (2321) (April 6, 2016)
*   ServicingAssetAtAmortizedValueValuationAllowance (2391) (April 6, 2016)
*   LiabilityForUnpaidClaimsAndClaimsAdjustmentExpenseIncurredClaims1 (1542) (January 1, 2017)

© Copyright 2015 - 2016, XBRL US Inc. All rights reserved.   
See [License](../../License.md) for license information.  
See [Patent Notice](../../PatentNotice.md) for patent infringement notice.
